"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Command = exports.Commands = exports.Client = void 0;
const commands_1 = __importDefault(require("./commands"));
exports.Command = commands_1.default;
const authorization_1 = require("./authorization");
const client_1 = require("./client");
class Commands {
    constructor() {
        this.tags = commands_1.default.ListTagsCommand;
        this.policy = commands_1.default.GetPolicyCommand;
        this.layers = commands_1.default.ListLayersCommand;
        this.sources = commands_1.default.ListEventSourceMappingsCommand;
        this.function = commands_1.default.GetFunctionCommand;
        this.versions = commands_1.default.ListVersionsByFunctionCommand;
        this.functions = commands_1.default.ListFunctionsCommand;
        this.invocation = commands_1.default.ListFunctionEventInvokeConfigsCommand;
        this.configuration = commands_1.default.GetFunctionConfigurationCommand;
        this.account = commands_1.default.GetAccountSettingsCommand;
    }
    static initialize() {
        return new Commands();
    }
}
exports.Commands = Commands;
/***
 * AWS Lambda Service Interface
 * ---
 *
 * While the `Client` defines and wraps the profile + credentials,
 * and initializes the `*.commands` attribute(s), `Service` extends
 * usage to AWS' Lambda API.
 *
 * @see {@link Constructor Lambda-Client}
 *
 * @example
 * @todo
 */
class Client extends authorization_1.Credential {
    constructor(profile = "default") {
        super(profile);
        this.commands = Commands.initialize();
        /// @ts-ignore
        this.service = new client_1.Constructor({});
    }
}
exports.Client = Client;
exports.default = { Client, Commands, Command: commands_1.default };
