import Command from "./commands";

import { Credential } from "./authorization";
import { Constructor } from "./client";

class Commands {
    public readonly tags = Command.ListTagsCommand;
    public readonly policy = Command.GetPolicyCommand;
    public readonly layers = Command.ListLayersCommand;
    public readonly sources = Command.ListEventSourceMappingsCommand;
    public readonly function = Command.GetFunctionCommand;
    public readonly versions = Command.ListVersionsByFunctionCommand;
    public readonly functions = Command.ListFunctionsCommand;
    public readonly invocation = Command.ListFunctionEventInvokeConfigsCommand;
    public readonly configuration = Command.GetFunctionConfigurationCommand;

    public readonly account = Command.GetAccountSettingsCommand;

    private constructor() {}

    public static initialize() {
        return new Commands();
    }
}

/***
 * AWS Lambda Service Interface
 * ---
 *
 * While the `Client` defines and wraps the profile + credentials,
 * and initializes the `*.commands` attribute(s), `Service` extends
 * usage to AWS' Lambda API.
 *
 * @see {@link Constructor Lambda-Client}
 *
 * @example
 * @todo
 */

class Client extends Credential {
    protected readonly commands = Commands.initialize();

    constructor( profile: string = "default" ) {
        super( profile );

        /// @ts-ignore
        this.service = new Constructor( {} );
    }
}

export { Client, Commands, Command };
export default { Client, Commands, Command };
