import { VpcConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { EnvironmentResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { TracingConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { Layer } from "@aws-sdk/client-lambda/dist-types/models";
import { FileSystemConfig } from "@aws-sdk/client-lambda/dist-types/models";
import { Architecture } from "@aws-sdk/client-lambda/dist-types/models";
import { Runtime } from "@aws-sdk/client-lambda/dist-types/models";
import { DeadLetterConfig } from "@aws-sdk/client-lambda/dist-types/models";
import { State } from "@aws-sdk/client-lambda/dist-types/models";
import { StateReasonCode } from "@aws-sdk/client-lambda/dist-types/models";
import { LastUpdateStatus } from "@aws-sdk/client-lambda/dist-types/models";
import { LastUpdateStatusReasonCode } from "@aws-sdk/client-lambda/dist-types/models";
import { PackageType } from "@aws-sdk/client-lambda/dist-types/models";
import { ImageConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";
/**
 * Details about a function's configuration
 */
interface Configuration {
    /**
     * The name of the function
     */
    FunctionName?: string;
    /**
     * The function's Amazon Resource Name (ARN)
     */
    FunctionArn?: string;
    /**
     * The runtime environment for the Lambda function
     */
    Runtime?: Runtime | string;
    /**
     * The function's execution role
     */
    Role?: string;
    /**
     * The function that Lambda calls to begin executing your function
     */
    Handler?: string;
    /**
     * The size of the function's deployment package, in bytes
     */
    CodeSize?: number;
    /**
     * The function's description
     */
    Description?: string;
    /**
     * The amount of time in seconds that Lambda allows a function to run before stopping it
     */
    Timeout?: number;
    /**
     * The amount of memory available to the function at runtime.
     */
    MemorySize?: number;
    /**
     * The date and time that the function was last updated, in <a href="https://www.w3.org/TR/NOTE-datetime">ISO-8601 format</a> (YYYY-MM-DDThh:mm:ss.sTZD
     */
    LastModified?: string;
    /**
     * The SHA256 hash of the function's deployment package
     */
    CodeSha256?: string;
    /**
     * The version of the Lambda function
     */
    Version?: string;
    /**
     * The function's networking configuration
     */
    VpcConfig?: VpcConfigResponse;
    /**
     * The function's dead letter queue
     */
    DeadLetterConfig?: DeadLetterConfig;
    /**
     * The function's <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html">environment variables</a
     */
    Environment?: EnvironmentResponse;
    /**
     * The KMS key that's used to encrypt the function's environment variables. This key is only returned if
     *       configured a customer managed key.</p>
     */
    KMSKeyArn?: string;
    /**
     * The function's X-Ray tracing configuration
     */
    TracingConfig?: TracingConfigResponse;
    /**
     * For Lambda@Edge functions, the ARN of the main function
     */
    MasterArn?: string;
    /**
     * The latest updated revision of the function or alias
     */
    RevisionId?: string;
    /**
     * The function's <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers
     *       layers</a>.</p>
     */
    Layers?: Layer[];
    /**
     * The current state of the function. When the state is <code>Inactive</code>, you can reactivate
     *       invoking it.</p>
     */
    State?: State | string;
    /**
     * The reason for the function's current state
     */
    StateReason?: string;
    /**
     * The reason code for the function's current state. When the code is <code>Creating</code>, you can'
     *       modify the function.</p>
     */
    StateReasonCode?: StateReasonCode | string;
    /**
     * The status of the last update that was performed on the function. This is first set to <code>Successful
     *       after function creation completes.</p>
     */
    LastUpdateStatus?: LastUpdateStatus | string;
    /**
     * The reason for the last update that was performed on the function
     */
    LastUpdateStatusReason?: string;
    /**
     * The reason code for the last update that was performed on the function
     */
    LastUpdateStatusReasonCode?: LastUpdateStatusReasonCode | string;
    /**
     * Connection settings for an <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html">Amazon EFS file system</a
     */
    FileSystemConfigs?: FileSystemConfig[];
    /**
     * The type of deployment package. Set to <code>Image</code> for container image and set <code>Zip</code> for .zip file archive
     */
    PackageType?: PackageType | string;
    /**
     * The function's image configuration values
     */
    ImageConfigResponse?: ImageConfigResponse;
    /**
     * The ARN of the signing profile version
     */
    SigningProfileVersionArn?: string;
    /**
     * The ARN of the signing job
     */
    SigningJobArn?: string;
    /**
     * The instruction set architecture that the function supports. Architecture is a string array with
     *       valid values. The default architecture value is <code>x86_64</code>.</p>
     */
    Architectures?: (Architecture | string)[];
}
declare class Function {
    FunctionName?: string | null | undefined;
    FunctionArn?: string | null | undefined;
    Runtime?: string | null | undefined;
    Role?: string | null | undefined;
    Handler?: string | null | undefined;
    CodeSize?: number | null | undefined;
    Description?: string | null | undefined;
    Timeout?: number | null | undefined;
    MemorySize?: number | null | undefined;
    LastModified?: string | null | undefined;
    CodeSha256?: string | null | undefined;
    Version?: string | null | undefined;
    VpcConfig?: VpcConfigResponse | null | undefined;
    DeadLetterConfig?: DeadLetterConfig | null | undefined;
    Environment?: EnvironmentResponse | null | undefined;
    KMSKeyArn?: string | null | undefined;
    TracingConfig?: TracingConfigResponse | null | undefined;
    MasterArn?: string | null | undefined;
    RevisionId?: string | null | undefined;
    Layers?: Layer[] | null | undefined;
    State?: string | null | undefined;
    StateReason?: string | null | undefined;
    StateReasonCode?: string | null | undefined;
    LastUpdateStatus?: string | null | undefined;
    LastUpdateStatusReason?: string | null | undefined;
    LastUpdateStatusReasonCode?: string | null | undefined;
    FileSystemConfigs?: FileSystemConfig[] | null | undefined;
    PackageType?: string | null | undefined;
    ImageConfigResponse?: ImageConfigResponse | null | undefined;
    SigningProfileVersionArn?: string | null | undefined;
    SigningJobArn?: string | null | undefined;
    Architectures?: string[] | null | undefined;
    constructor(properties: Configuration);
}
declare class Functions extends Array {
    constructor(response: Configuration[]);
    serialize(pretty?: boolean): string;
}
export type { Configuration };
declare const _default: {
    Functions: typeof Functions;
    Function: typeof Function;
};
export default _default;
export { Functions, Function };
export declare type Data = Function[];
//# sourceMappingURL=function.d.ts.map