import { VpcConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { EnvironmentResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { TracingConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";
import { Layer } from "@aws-sdk/client-lambda/dist-types/models";
import { FileSystemConfig } from "@aws-sdk/client-lambda/dist-types/models";
import { Architecture } from "@aws-sdk/client-lambda/dist-types/models";
import { Runtime } from "@aws-sdk/client-lambda/dist-types/models";
import { DeadLetterConfig } from "@aws-sdk/client-lambda/dist-types/models";
import { State } from "@aws-sdk/client-lambda/dist-types/models";
import { StateReasonCode } from "@aws-sdk/client-lambda/dist-types/models";
import { LastUpdateStatus } from "@aws-sdk/client-lambda/dist-types/models";
import { LastUpdateStatusReasonCode } from "@aws-sdk/client-lambda/dist-types/models";
import { PackageType } from "@aws-sdk/client-lambda/dist-types/models";
import { ImageConfigResponse } from "@aws-sdk/client-lambda/dist-types/models";

/**
 * Details about a function's configuration
 */
interface Configuration {
    /**
     * The name of the function
     */
    FunctionName?: string;
    /**
     * The function's Amazon Resource Name (ARN)
     */
    FunctionArn?: string;
    /**
     * The runtime environment for the Lambda function
     */
    Runtime?: Runtime | string;
    /**
     * The function's execution role
     */
    Role?: string;
    /**
     * The function that Lambda calls to begin executing your function
     */
    Handler?: string;
    /**
     * The size of the function's deployment package, in bytes
     */
    CodeSize?: number;
    /**
     * The function's description
     */
    Description?: string;
    /**
     * The amount of time in seconds that Lambda allows a function to run before stopping it
     */
    Timeout?: number;
    /**
     * The amount of memory available to the function at runtime.
     */
    MemorySize?: number;
    /**
     * The date and time that the function was last updated, in <a href="https://www.w3.org/TR/NOTE-datetime">ISO-8601 format</a> (YYYY-MM-DDThh:mm:ss.sTZD
     */
    LastModified?: string;
    /**
     * The SHA256 hash of the function's deployment package
     */
    CodeSha256?: string;
    /**
     * The version of the Lambda function
     */
    Version?: string;
    /**
     * The function's networking configuration
     */
    VpcConfig?: VpcConfigResponse;
    /**
     * The function's dead letter queue
     */
    DeadLetterConfig?: DeadLetterConfig;
    /**
     * The function's <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html">environment variables</a
     */
    Environment?: EnvironmentResponse;
    /**
     * The KMS key that's used to encrypt the function's environment variables. This key is only returned if
     *       configured a customer managed key.</p>
     */
    KMSKeyArn?: string;
    /**
     * The function's X-Ray tracing configuration
     */
    TracingConfig?: TracingConfigResponse;
    /**
     * For Lambda@Edge functions, the ARN of the main function
     */
    MasterArn?: string;
    /**
     * The latest updated revision of the function or alias
     */
    RevisionId?: string;
    /**
     * The function's <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers
     *       layers</a>.</p>
     */
    Layers?: Layer[];
    /**
     * The current state of the function. When the state is <code>Inactive</code>, you can reactivate
     *       invoking it.</p>
     */
    State?: State | string;
    /**
     * The reason for the function's current state
     */
    StateReason?: string;
    /**
     * The reason code for the function's current state. When the code is <code>Creating</code>, you can'
     *       modify the function.</p>
     */
    StateReasonCode?: StateReasonCode | string;
    /**
     * The status of the last update that was performed on the function. This is first set to <code>Successful
     *       after function creation completes.</p>
     */
    LastUpdateStatus?: LastUpdateStatus | string;
    /**
     * The reason for the last update that was performed on the function
     */
    LastUpdateStatusReason?: string;
    /**
     * The reason code for the last update that was performed on the function
     */
    LastUpdateStatusReasonCode?: LastUpdateStatusReasonCode | string;
    /**
     * Connection settings for an <a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html">Amazon EFS file system</a
     */
    FileSystemConfigs?: FileSystemConfig[];
    /**
     * The type of deployment package. Set to <code>Image</code> for container image and set <code>Zip</code> for .zip file archive
     */
    PackageType?: PackageType | string;
    /**
     * The function's image configuration values
     */
    ImageConfigResponse?: ImageConfigResponse;
    /**
     * The ARN of the signing profile version
     */
    SigningProfileVersionArn?: string;
    /**
     * The ARN of the signing job
     */
    SigningJobArn?: string;
    /**
     * The instruction set architecture that the function supports. Architecture is a string array with
     *       valid values. The default architecture value is <code>x86_64</code>.</p>
     */
    Architectures?: (Architecture | string)[];
}

class Function {
    FunctionName?;
    FunctionArn?;
    Runtime?;
    Role?;
    Handler?;
    CodeSize?;
    Description?;
    Timeout?;
    MemorySize?;
    LastModified?;
    CodeSha256?;
    Version?;
    VpcConfig?;
    DeadLetterConfig?;
    Environment?;
    KMSKeyArn?;
    TracingConfig?;
    MasterArn?;
    RevisionId?;
    Layers?;
    State?;
    StateReason?;
    StateReasonCode?;
    LastUpdateStatus?;
    LastUpdateStatusReason?;
    LastUpdateStatusReasonCode?;
    FileSystemConfigs?;
    PackageType?;
    ImageConfigResponse?;
    SigningProfileVersionArn?;
    SigningJobArn?;
    Architectures?;

    constructor(properties: Configuration) {
        this.FunctionName = properties.FunctionName ?? null;
        this.FunctionArn = properties.FunctionArn ?? null;
        this.Runtime = properties.Runtime ?? null;
        this.Role = properties.Role ?? null;
        this.Handler = properties.Handler ?? null;
        this.CodeSize = properties.CodeSize ?? null;
        this.Description = properties.Description ?? null;
        this.Timeout = properties.Timeout ?? null;
        this.MemorySize = properties.MemorySize ?? null;
        this.LastModified = properties.LastModified ?? null;
        this.CodeSha256 = properties.CodeSha256 ?? null;
        this.Version = properties.Version ?? null;
        this.VpcConfig = properties.VpcConfig ?? null;
        this.DeadLetterConfig = properties.DeadLetterConfig ?? null;
        this.Environment = properties.Environment ?? null;
        this.KMSKeyArn = properties.KMSKeyArn ?? null;
        this.TracingConfig = properties.TracingConfig ?? null;
        this.MasterArn = properties.MasterArn ?? null;
        this.RevisionId = properties.RevisionId ?? null;
        this.Layers = properties.Layers ?? null;
        this.State = properties.State ?? null;
        this.StateReason = properties.StateReason ?? null;
        this.StateReasonCode = properties.StateReasonCode ?? null;
        this.LastUpdateStatus = properties.LastUpdateStatus ?? null;
        this.LastUpdateStatusReason = properties.LastUpdateStatusReason ?? null;
        this.LastUpdateStatusReasonCode = properties.LastUpdateStatusReasonCode ?? null;
        this.FileSystemConfigs = properties.FileSystemConfigs ?? null;
        this.PackageType = properties.PackageType ?? null;
        this.ImageConfigResponse = properties.ImageConfigResponse ?? null;
        this.SigningProfileVersionArn = properties.SigningProfileVersionArn ?? null;
        this.SigningJobArn = properties.SigningJobArn ?? null;
        this.Architectures = properties.Architectures ?? null;
    }
}

class Functions extends Array {
    constructor( response: Configuration[] ) {
        super();

        ( response ) && response.forEach( ( $ ) => {
            this.push( new Function( { ... $ } ) );
        } );
    }

    public serialize( pretty?: boolean ) {
        return JSON.stringify( this, null, ( pretty ) ? 4 : undefined );
    }
}

export type { Configuration };
export default { Functions, Function };
export { Functions, Function };

export type Data = Function[];
