"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Service = void 0;
const aws_1 = require("./aws");
const utility_1 = require("./utility");
const function_1 = require("./function");
const commands_1 = __importDefault(require("./commands"));
/***
 * AWS Lambda Service Interface
 * ---
 *
 * While the `Client` defines and wraps the profile + credentials,
 * and initializes the `*.commands` attribute(s), `Service` extends
 * usage to AWS' Lambda API.
 *
 * @see {@link Client}
 *
 * @example
 */
class Service extends aws_1.Client {
    constructor(profile = "default") {
        super(profile);
    }
    /***
     * List all AWS Account Lambda Functions(s)
     */
    functions(debug = false) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.hydrate();
            const pointer = { $: [], paginator: { token: null } };
            Reflect.set(pointer, "$", []);
            const container = Reflect.get(pointer, "$");
            const invoke = (token) => __awaiter(this, void 0, void 0, function* () {
                var _a;
                const command = Service.constructors.ListFunctionsCommand({
                    Marker: (token !== null)
                        ? token
                        : undefined,
                    MaxItems: 50
                });
                const page = yield this.service.send(command);
                page && ((_a = page === null || page === void 0 ? void 0 : page.Functions) === null || _a === void 0 ? void 0 : _a.forEach(($) => {
                    container.push($);
                }));
                const pager = page === null || page === void 0 ? void 0 : page.NextMarker;
                yield (0, utility_1.Awaitable)(1500, "Functions", debug);
                return pager !== null && pager !== void 0 ? pager : null;
            });
            pointer.paginator.token = yield invoke();
            do {
                pointer.paginator.token = yield invoke(pointer.paginator.token);
            } while (pointer.paginator.token !== null);
            return new function_1.Functions(container);
        });
    }
}
exports.Service = Service;
Service.constructors = commands_1.default;
exports.default = { Service };
