import { Client } from "./aws";

import { Awaitable } from "./utility";

import { Functions } from "./function";

import Commands, { Constructor } from "./commands";

/***
 * AWS Lambda Service Interface
 * ---
 *
 * While the `Client` defines and wraps the profile + credentials,
 * and initializes the `*.commands` attribute(s), `Service` extends
 * usage to AWS' Lambda API.
 *
 * @see {@link Client}
 *
 * @example
 */

class Service extends Client {
    static constructors: Constructor = Commands;
    constructor(profile: string = "default") {
        super( profile );
    }

    /***
     * List all AWS Account Lambda Functions(s)
     */

    public async functions(debug: boolean = false): Promise<Functions> {
        await this.hydrate();

        const pointer: { $: Functions | []; paginator: { token: string | undefined | null } } = { $: [], paginator: { token: null } };

        Reflect.set( pointer, "$", [] );

        const container = Reflect.get( pointer, "$" );

        const invoke = async (token?: string | null) => {
            const command = Service.constructors.ListFunctionsCommand({
                Marker: ( token !== null )
                    ? token
                    : undefined,
                MaxItems: 50
            });

            const page = await this.service!.send( command );

            page && page?.Functions?.forEach( ($) => {
                container.push( $ );
            } );

            const pager = page?.NextMarker;

            await Awaitable( 1500, "Functions", debug );

            return pager ?? null;
        };

        pointer.paginator.token = await invoke();

        do {
            pointer.paginator.token = await invoke( pointer.paginator.token );
        } while ( pointer.paginator.token !== null );

        return new Functions( container );
    }
}

export { Service };

export default { Service };
